package iniwrap;

use strict;
use Fcntl qw (:flock);
use Plugins;
use Log;

Plugins::register('iniwrap', '', \&Unload);

my $chooks = Commands::register(
	['inir', "", \&iniread],
	['iniw', "", \&iniwrite]
);

my $hooks = Plugins::addHooks(
	['mainLoop_pre', \&call]
);

sub call {
	my $file = "iniwrap.ini";	# ini file we use
	my $key1 = "playerisclose";	# key we scan
	my $value1 = "true";		# key value that triggeres the further execution of the subroutine

	open (FILE, $file);
	flock(FILE, LOCK_SH);
	my @lines = <FILE>;
	flock(FILE, LOCK_UN);
	close (FILE);
	chomp @lines;

	foreach my $line (@lines) {
		next if length $line == 0;

		my ($what,$is) = split(/=/, $line, 2);

		if(($what eq $key1) && ($is eq $value1)) {
			Log::message("File event handled!\n"); # Key value is changed to 'handled'
			iniwrite("", "iniwrap.ini playerisclose handled");
			return 1;
		}
	}
	return 1;
}

sub iniread {
	my ($a, $args) = @_;
	my ($file, $key1) = split(" ", $args, 2);
	if (!defined $file) {
		Log::message("inir <file name> [<key>]\n");
		return;
	}

	open (FILE, $file);
	flock(FILE, LOCK_SH);
	my @lines = <FILE>;
	flock(FILE, LOCK_UN);
	close (FILE);
	chomp @lines;

	if (!defined $key1) {
		foreach my $line (@lines) {
			next if length $line == 0;
			Log::message($line."\n");
		}
		return;
	}

	my $value;
	foreach my $line (@lines) {
		next if length $line == 0;

		my ($what,$is) = split(/=/, $line, 2);

		if($what eq $key1) {
			Log::message($is."\n");
			return 1;
		}
	}
	Log::message("Key was not found.\n");
	return 1;
}
sub iniwrite {
	my $args = $_[1];
	my ($file, $key1, $value1) = split(" ", $args, 3);
	if (!defined $file || !defined $key1 || !defined $value1) {
		Log::message("iniw <file name> <key> <value>\n");
		return;
	}

	open (FILE, $file);
	flock(FILE, LOCK_SH);
	my @lines = <FILE>;
	flock(FILE, LOCK_UN);
	close (FILE);
	chomp @lines;

	my @new = ();
	my $used = 0;
	foreach my $line (@lines) {

		if (length $line == 0) {
			push (@new, $line);
			next;
		}

		my ($what,$is) = split(/=/, $line, 2);

		$line = join ('=', $what, $is);

		if($what eq $key1) {
			$line = join ('=', $key1, $value1);
			$used = 1;
		}

		push (@new, $line);
	}
	if($used == 0){
		push (@new, $key1."=".$value1);
	}

	my $eol = "\n";
	open (WRITE, ">$file");
	flock(WRITE, LOCK_EX);
	print WRITE join ($eol, @new);
	flock(WRITE, LOCK_UN);
	close (WRITE);

	return 1;
}

sub Unload {
	Commands::unregister($chooks);
	Plugins::delHooks($hooks);
}